@@ -1,7 +1,7 @@
-import cffi
-import re
 import enum
 
+import cffi
+
 ################################################################
 # Functions and types
 ################################################################
@@ -15,33 +15,8 @@ BOOL PeekNamedPipe(
   LPDWORD lpTotalBytesAvail,
   LPDWORD lpBytesLeftThisMessage
 );
-
-BOOL GetNamedPipeHandleStateA(
-  HANDLE  hNamedPipe,
-  LPDWORD lpState,
-  LPDWORD lpCurInstances,
-  LPDWORD lpMaxCollectionCount,
-  LPDWORD lpCollectDataTimeout,
-  LPSTR   lpUserName,
-  DWORD   nMaxUserNameSize
-);
-
 """
 
-# cribbed from pywincffi
-# programmatically strips out those annotations MSDN likes, like _In_
-REGEX_SAL_ANNOTATION = re.compile(
-    r"\b(_In_|_Inout_|_Out_|_Outptr_|_Reserved_)(opt_)?\b"
-)
-LIB = REGEX_SAL_ANNOTATION.sub(" ", LIB)
-
-# Other fixups:
-# - get rid of FAR, cffi doesn't like it
-LIB = re.sub(r"\bFAR\b", " ", LIB)
-# - PASCAL is apparently an alias for __stdcall (on modern compilers - modern
-#   being _MSC_VER >= 800)
-LIB = re.sub(r"\bPASCAL\b", "__stdcall", LIB)
-
 ffi = cffi.FFI()
 ffi.cdef(LIB)
 
@@ -74,18 +49,11 @@ class ErrorCodes(enum.IntEnum):
     ERROR_MORE_DATA = 234
 
 
-class PipeModes(enum.IntFlag):
-    PIPE_WAIT = 0x00000000
-    PIPE_NOWAIT = 0x00000001
-    PIPE_READMODE_BYTE = 0x00000000
-    PIPE_READMODE_MESSAGE = 0x00000002
-
-
 ################################################################
 # Generic helpers
 ################################################################
 
-
+# vendored from trio, so no coverage
 def _handle(obj):  # pragma: no cover
     # For now, represent handles as either cffi HANDLEs or as ints.  If you
     # try to pass in a file descriptor instead, it's not going to work
@@ -99,6 +67,7 @@ def _handle(obj):  # pragma: no cover
         return obj
 
 
+# vendored from trio, so no coverage
 def raise_winerror(winerror=None, *, filename=None, filename2=None):  # pragma: no cover
     if winerror is None:
         winerror, msg = ffi.getwinerror()
