@@ -15,15 +15,16 @@ class PipeSendChannel(SendChannel[bytes]):
 
     def __init__(self, handle: int) -> None:
         self._pss = PipeSendStream(handle)
-        # needed for "detach" via _handle_holder.handle = -1
-        self._handle_holder = self._pss._handle_holder
 
     async def send(self, value: bytes):
         # Works just fine if the pipe is message-oriented
         await self._pss.send_all(value)
 
-    async def aclose(self):  # pragma: no cover
-        await self._handle_holder.aclose()
+    def detach(self):
+        self._pss._handle_holder.handle = -1
+
+    async def aclose(self):  # pragma: no cover, not used in this lib
+        await self._pss._handle_holder.aclose()
 
 
 class PipeReceiveChannel(ReceiveChannel[bytes]):
@@ -42,7 +43,7 @@ class PipeReceiveChannel(ReceiveChannel[bytes]):
                 received = await self._receive_some_into(buffer)
             except OSError as e:
                 if e.winerror != ErrorCodes.ERROR_MORE_DATA:
-                    raise  # pragma: no cover
+                    raise  # pragma: no cover, real OSError we can't generate
                 left = peek_pipe_message_left(self._handle_holder.handle)
                 # preallocate memory to avoid an extra copy of very large messages
                 newbuffer = bytearray(DEFAULT_RECEIVE_SIZE + left)
@@ -56,14 +57,14 @@ class PipeReceiveChannel(ReceiveChannel[bytes]):
                 return buffer
 
     async def _receive_some_into(self, buffer):
-        if self._handle_holder.closed:  # pragma: no cover
+        if self._handle_holder.closed:  # pragma: no cover, never closed in this lib
             raise trio.ClosedResourceError("this pipe is already closed")
         try:
             return await trio.lowlevel.readinto_overlapped(
                 self._handle_holder.handle, buffer
             )
         except BrokenPipeError:
-            if self._handle_holder.closed:  # pragma: no cover
+            if self._handle_holder.closed:  # pragma: no cover, never closed in this lib
                 raise trio.ClosedResourceError(
                     "another task closed this pipe"
                 ) from None
@@ -76,5 +77,8 @@ class PipeReceiveChannel(ReceiveChannel[bytes]):
             # in contrast to PipeReceiveStream.
             raise trio.EndOfChannel
 
-    async def aclose(self):  # pragma: no cover
+    def detach(self):
+        self._handle_holder.handle = -1
+
+    async def aclose(self):  # pragma: no cover, not used in this lib
         await self._handle_holder.aclose()
